==> 5.8.0.tar.gz: ciphey/translations/pt-br/CONTRIBUTING.md <==
Olá! 

Então você está interessado em contribuir com Ciphey? 🤔

Talves você esteja confudo em onde começar, ou você acredita que suas habilidades em escrever código não são "boas o bastante"? Bom, para a segunda opção - isso é ridículo! Nós estamos de boa com "código ruim" e mesmo assim, se você está lendo esse documento, você provavelmente é um programador bom. Quer dizer, iniciantes normalmente não aprendem a contribuir em projetos do GitHub. 😉

Aqui estão algumas maneiras de contribuir com Ciphey:
* Adicione uma linguagem nova 🧏
* Adicione metodos de criptografia 📚
* Crie mais documentação (muito importante! Nós seriamos eternamente gratos)
* Resolva bugs nas questoes do GitHub (nós podemos te ajudar nisso 😊)
* Refatore o código 🥺

Se esses parecem difíceis, não se preocupe! Esse documento vai te ensinar exatamente como alcançar qualquer um desses. Além disso, seu nome será adicionado para a lista de contribuidores do Ciphey e nós seremos eternamente gratos! 🙏


Nós temos um pequeno chat do Discord para você conversar com os desenvolvedores e receber uma ajuda. Alternativamente, você pode escrever uma issue no GitHub para a sua sugestão. Se você quiser ser adicionado no Discord, mande uma DM ou nos pergunte de alguma maneira.

[Servidor do Discord](https://discord.gg/KfyRUWw)
# Como contribuir
Ciphey sempre precisa mais ferramentas de descriptografia! Para aprender como integrar código no Ciphey, dê uma olhada:
* https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers para um tutorial simples
* https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey para a referência da API

Seria bom se você escrever testes, simplesmente copiando a função em Ciphey/tests/test_main.py e substituindo o texto cifrado por algo codificado pela sua cifra. Se você não adicionar testes, nós provavelmente ainda aceitaremos, mas vai ser muito mais difícil para nós diagnosticar os bugs!

Não precisa nem dizer que nós adicionaremos você para a lista de contribuidores por seu trabalho duro!

# Adicionar uma linguagem nova 🧏
O verificador de linguagem padrão, `brandon`, trabalha com multiplas linguagens. Agora, isso pode soar assustador.
Mas honestamente, tudo oque você deve fazer é pegar um dicionário, fazer uma pequena análise (nós escrevemos código para te ajudar com isso), adicionar os dicionários e análise para o repositório. E então adicionar a opção para `settings.yml`.

# Criar mais documentação
Documentação é a parte mais importante de Ciphey. Sem documentação o codigo fica dificil de entender e nós não queremos isso.

Acredite quando eu digo, se você contribuir com boa documentação, você será visto no mesmo nível de contribuidores de códifo. Documentação é absolutamente vital.

Existem várias maneiras de adicionar documentação.
* Documentando strings no código
* Melhorando a documentação atual (README, esse arquivo, as paginas Wiki do Ciphey)
* Traduzindo documentação

E muito mais!

# Resolver bugs
Visite nossa página de GitHub issues para encontrar todos os bugs que Ciphey tem! Acabe com eles e você será adicionado na lista de contribuidores. ;)

# Refactorar o código
Nem todo código de Ciphey segue PEP8 e uma parte do código é repetida.

==> 5.10.0.tar.gz: ciphey/translations/pt-br/CONTRIBUTING.md <==
Olá!

Então você está interessado em contribuir com Ciphey? 🤔

Talves você esteja confudo em onde começar, ou você acredita que suas habilidades em escrever código não são "boas o bastante"? Bom, para a segunda opção - isso é ridículo! Nós estamos de boa com "código ruim" e mesmo assim, se você está lendo esse documento, você provavelmente é um programador bom. Quer dizer, iniciantes normalmente não aprendem a contribuir em projetos do GitHub. 😉

Aqui estão algumas maneiras de contribuir com Ciphey:

- Adicione uma linguagem nova 🧏
- Adicione metodos de criptografia 📚
- Crie mais documentação (muito importante! Nós seriamos eternamente gratos)
- Resolva bugs nas questoes do GitHub (nós podemos te ajudar nisso 😊)
- Refatore o código 🥺

Se esses parecem difíceis, não se preocupe! Esse documento vai te ensinar exatamente como alcançar qualquer um desses. Além disso, seu nome será adicionado para a lista de contribuidores do Ciphey e nós seremos eternamente gratos! 🙏

Nós temos um pequeno chat do Discord para você conversar com os desenvolvedores e receber uma ajuda. Alternativamente, você pode escrever uma issue no GitHub para a sua sugestão. Se você quiser ser adicionado no Discord, mande uma DM ou nos pergunte de alguma maneira.

[Servidor do Discord](https://discord.gg/KfyRUWw)

# Como contribuir

Ciphey sempre precisa mais ferramentas de descriptografia! Para aprender como integrar código no Ciphey, dê uma olhada:

- <https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers> para um tutorial simples
- <https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey> para a referência da API

Seria bom se você escrever testes, simplesmente copiando a função em Ciphey/tests/test_main.py e substituindo o texto cifrado por algo codificado pela sua cifra. Se você não adicionar testes, nós provavelmente ainda aceitaremos, mas vai ser muito mais difícil para nós diagnosticar os bugs!

Não precisa nem dizer que nós adicionaremos você para a lista de contribuidores por seu trabalho duro!

# Adicionar uma linguagem nova 🧏

O verificador de linguagem padrão, `brandon`, trabalha com multiplas linguagens. Agora, isso pode soar assustador.
Mas honestamente, tudo oque você deve fazer é pegar um dicionário, fazer uma pequena análise (nós escrevemos código para te ajudar com isso), adicionar os dicionários e análise para o repositório. E então adicionar a opção para `settings.yml`.

# Criar mais documentação

Documentação é a parte mais importante de Ciphey. Sem documentação o codigo fica dificil de entender e nós não queremos isso.

Acredite quando eu digo, se você contribuir com boa documentação, você será visto no mesmo nível de contribuidores de códifo. Documentação é absolutamente vital.

Existem várias maneiras de adicionar documentação.

- Documentando strings no código
- Melhorando a documentação atual (README, esse arquivo, as paginas Wiki do Ciphey)
- Traduzindo documentação

E muito mais!

# Resolver bugs

Visite nossa página de GitHub issues para encontrar todos os bugs que Ciphey tem! Acabe com eles e você será adicionado na lista de contribuidores. ;)

# Refactorar o código

Nem todo código de Ciphey segue PEP8 e uma parte do código é repetida.
